/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/*
 * ======== hal.h ========
 *
 * Device and board specific pins need to be configured here
 *
 */

// User Libraries
#include "driverlib.h"
//#include "msp430.h"
//#include "USB_API/USB_Common/device.h"
//#include "USB_config/descriptors.h"

// C Standard Libraries
#include <stdint.h>							// Defines exact width integer types

// DEBUG
//#define NDEBUG							// Define to remove debug assertions (i.e. assert() function)

// Define Hardware Connections Here
#define LED_PORT			GPIO_PORT_P1
#define LED_PIN				GPIO_PIN0

#define DRDY_PORT			GPIO_PORT_P1
#define DRDY_PIN			GPIO_PIN2

#define START_PORT			GPIO_PORT_P2
#define START_PIN			GPIO_PIN7

#define CS_PORT				GPIO_PORT_P8
#define CS_PIN				GPIO_PIN1

#define SPI_PORT			GPIO_PORT_P3
#define MOSI_PIN			GPIO_PIN0
#define MISO_PIN			GPIO_PIN1
#define SCLK_PIN			GPIO_PIN2

#define RST_PWDN_PORT		GPIO_PORT_P8
#define RST_PWDN_PIN		GPIO_PIN2

//If the nDRDY pin is modified, update the cooresponding ISR vector in "interrupts.c"
#define DRDY_PORT			GPIO_PORT_P1
#define DRDY_PIN			GPIO_PIN2


// Crystal definitions for LaunchPad MSP-EXP430F5529LP, change to frequencies present on board
#define XT1FREQ 32768
#define XT2FREQ 4000000

// System clock definition, change to desired frequency
#define SYSFREQ 25000000
#define UARTBAUD 921600

// Software delays, change as required for SPI timing delays
#define Delay80ns 2				// Called as "__delay_cycles(Delay80ns);" ... (2/SYSFREQ) ~= 80 ns
								// this delay time is sufficent for most ADS126x SPI timing requirements
#define Delay50ms 1250000		// Called as "__delay_cycles(Delay100ms);"
#define Delay100ms 2500000		// Called as "__delay_cycles(Delay100ms);"

// LED toggle delays
#define SLOW_TOOGLE_PERIOD	19999
#define FAST_TOGGLE_PERIOD 	  999

// UART Baudrate register configuration, don't touch!
#if UARTBAUD == 921600
	#define UART_PRESCALER 27
	#define UART_FIRSTMODREG 0
	#define UART_SECONDMODREG 1
	#define UART_OVERSAMPLING USCI_A_UART_LOW_FREQUENCY_BAUDRATE_GENERATION
#elif UARTBAUD == 460800
	#define UART_PRESCALER 3
	#define UART_FIRSTMODREG 5
	#define UART_SECONDMODREG 3
	#define UART_OVERSAMPLING USCI_A_UART_OVERSAMPLING_BAUDRATE_GENERATION
#elif UARTBAUD == 230400
	#define UART_PRESCALER 6
	#define UART_FIRSTMODREG 11
	#define UART_SECONDMODREG 2
	#define UART_OVERSAMPLING USCI_A_UART_OVERSAMPLING_BAUDRATE_GENERATION
#elif UARTBAUD == 115200
	#define UART_PRESCALER 13
	#define UART_FIRSTMODREG 9
	#define UART_SECONDMODREG 0
	#define UART_OVERSAMPLING USCI_A_UART_OVERSAMPLING_BAUDRATE_GENERATION
#elif UARTBAUD == 38400
	#define UART_PRESCALER 40
	#define UART_FIRSTMODREG 11
	#define UART_SECONDMODREG 0
	#define UART_OVERSAMPLING USCI_A_UART_OVERSAMPLING_BAUDRATE_GENERATION
#else
	#error "Unknown baud rate for UART"
#endif


// Public Function Protoypes
void initPorts(void);
void initClocks(void);
void initSPI(void);
void initTimer(void);
void WaitForDRDY(void);

//External Global Variables
extern volatile uint8_t g_DRDY_flag;

//extern uint16_t g_excitationCounter;
//extern uint8_t g_packetCounter;

//Released_Version_4_10_02
